You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@datafusion.apache.org by "alamb (via GitHub)" <gi...@apache.org> on 2025/11/21 20:19:20 UTC
Re: [PR] TEST: enable pushdown_filters and reorder_filters by default [datafusion]
alamb commented on PR #18873:
URL: https://github.com/apache/datafusion/pull/18873#issuecomment-3564467238
I am also testing with just `filter_pushdown` on:
- https://github.com/apache/datafusion/pull/18874
I am going to focus my efforts on profiling these queries which seem to have gotten the most slower:
```
│ QQuery 24 │ 215.96 ms │ 253.74 ms │ 1.17x slower │
│ QQuery 25 │ 489.11 ms │ 617.52 ms │ 1.26x slower │
│ QQuery 26 │ 228.11 ms │ 324.39 ms │ 1.42x slower │
```
Here is the query:
```shell
set datafusion.execution.parquet.binary_as_string = true
SELECT "SearchPhrase" FROM hits WHERE "SearchPhrase" <> '' ORDER BY "SearchPhrase" LIMIT 10;
````
Basically my next steps are to profile these queries and see what is slower (and if it is related to filter representation, I will go focus on https://github.com/apache/arrow-rs/pull/8902)
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org
---------------------------------------------------------------------
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For additional commands, e-mail: github-help@datafusion.apache.org